@@ -388,7 +388,8 @@ def gen_ucd() -> None:
                 rmap[0xfe0e], rmap[0xfe0f]
             ))
     with open('kittens/hints/url_regex.py', 'w') as f:
-        f.write("url_delimiters = '{}'  # noqa".format(''.join(classes_to_regex(cz, exclude='\n'))))
+        f.write('# generated by gen-wcwidth.py, do not edit\n\n')
+        f.write("url_delimiters = '{}'  # noqa".format(''.join(classes_to_regex(cz, exclude='\n\r'))))
 
 
 def gen_names() -> None:
