@@ -102,7 +102,7 @@ def goto_tab_parse(func: str, rest: str) -> FuncArgsType:
 
 @func_with_args('detach_window')
 def detach_window_parse(func: str, rest: str) -> FuncArgsType:
-    if rest not in ('new', 'new-tab', 'ask'):
+    if rest not in ('new', 'new-tab', 'ask', 'tab-prev', 'tab-left', 'tab-right'):
         log_error('Ignoring invalid detach_window argument: {}'.format(rest))
         rest = 'new'
     return func, (rest,)
@@ -116,7 +116,7 @@ def detach_tab_parse(func: str, rest: str) -> FuncArgsType:
     return func, (rest,)
 
 
-@func_with_args('set_background_opacity', 'goto_layout', 'kitty_shell')
+@func_with_args('set_background_opacity', 'goto_layout', 'toggle_layout', 'kitty_shell')
 def simple_parse(func: str, rest: str) -> FuncArgsType:
     return func, [rest]
 
@@ -341,6 +341,7 @@ def mouse_selection(func: str, rest: str) -> FuncArgsType:
         cmap = {
             'normal': defines.MOUSE_SELECTION_NORMAL,
             'extend': defines.MOUSE_SELECTION_EXTEND,
+            'move-end': defines.MOUSE_SELECTION_MOVE_END,
             'rectangle': defines.MOUSE_SELECTION_RECTANGLE,
             'word': defines.MOUSE_SELECTION_WORD,
             'line': defines.MOUSE_SELECTION_LINE,
@@ -613,7 +614,7 @@ def tab_fade(x: str) -> Tuple[float, ...]:
 def tab_activity_symbol(x: str) -> Optional[str]:
     if x == 'none':
         return None
-    return x or None
+    return tab_title_template(x) or None
 
 
 def tab_title_template(x: str) -> str:
