@@ -223,6 +223,7 @@ class Tab:  # {{{
         return create_layout_object_for(name, self.os_window_id, self.id)
 
     def next_layout(self) -> None:
+        '@ac:lay: Go to the next enabled layout'
         if len(self.enabled_layouts) > 1:
             for i, layout_name in enumerate(self.enabled_layouts):
                 if layout_name == self.current_layout.full_name:
@@ -235,11 +236,19 @@ class Tab:  # {{{
             self.relayout()
 
     def last_used_layout(self) -> None:
+        '@ac:lay: Go to the previously used layout'
         if len(self.enabled_layouts) > 1 and self._last_used_layout and self._last_used_layout != self._current_layout_name:
             self._set_current_layout(self._last_used_layout)
             self.relayout()
 
     def goto_layout(self, layout_name: str, raise_exception: bool = False) -> None:
+        '''
+        @ac:lay: Switch to the named layout
+
+        For example::
+
+            map f1 goto_layout tall
+        '''
         layout_name = layout_name.lower()
         if layout_name not in self.enabled_layouts:
             if raise_exception:
@@ -249,6 +258,21 @@ class Tab:  # {{{
         self._set_current_layout(layout_name)
         self.relayout()
 
+    def toggle_layout(self, layout_name: str) -> None:
+        '''
+        @ac:lay: Toggle the named layout
+
+        Switches to the named layout if another layout is current, otherwise
+        switches to the last used layout. Useful to "zoom" a window temporarily
+        by switching to the stack layout. For example::
+
+            map f1 toggle_layout stack
+        '''
+        if self._current_layout_name == layout_name:
+            self.last_used_layout()
+        else:
+            self.goto_layout(layout_name)
+
     def resize_window_by(self, window_id: int, increment: float, is_horizontal: bool) -> Optional[str]:
         increment_as_percent = self.current_layout.bias_increment_for_cell(is_horizontal) * increment
         if self.current_layout.modify_size_of_window(self.windows, window_id, increment_as_percent, is_horizontal):
@@ -257,6 +281,11 @@ class Tab:  # {{{
         return 'Could not resize'
 
     def resize_window(self, quality: str, increment: int) -> None:
+        '''
+        @ac:win: Resize the active window by the specified amount
+
+        See :ref:`window_resizing` for details.
+        '''
         if increment < 1:
             raise ValueError(increment)
         is_horizontal = quality in ('wider', 'narrower')
@@ -264,13 +293,16 @@ class Tab:  # {{{
         w = self.active_window
         if w is not None and self.resize_window_by(
                 w.id, increment, is_horizontal) is not None:
-            ring_bell()
+            if get_options().enable_audio_bell:
+                ring_bell()
 
     def reset_window_sizes(self) -> None:
+        '@ac:win:Reset window sizes undoing any dynamic resizing of windows'
         if self.current_layout.remove_all_biases():
             self.relayout()
 
     def layout_action(self, action_name: str, args: Sequence[str]) -> None:
+        '@ac:lay: Perform a layout specific action. See :doc:`layouts` for details'
         ret = self.current_layout.layout_action(action_name, args, self.windows)
         if ret is None:
             ring_bell()
@@ -393,11 +425,13 @@ class Tab:  # {{{
         )
 
     def close_window(self) -> None:
+        '@ac:win: Close the currently active window'
         w = self.active_window
         if w is not None:
             self.remove_window(w)
 
     def close_other_windows_in_tab(self) -> None:
+        '@ac:win: Close all windows in the tab other than the currently active window'
         if len(self.windows) > 1:
             active_window = self.active_window
             for window in tuple(self.windows):
@@ -436,6 +470,13 @@ class Tab:  # {{{
             return self.current_layout.nth_window(self.windows, n)
 
     def nth_window(self, num: int = 0) -> None:
+        '''
+        @ac:win: Focus the nth window if positive or the previously active windows if negative
+
+        For example, to ficus the previously active window::
+
+            map ctrl+p nth_window -1
+        '''
         if self.windows:
             if num < 0:
                 self.windows.make_previous_group_active(-num)
@@ -449,9 +490,11 @@ class Tab:  # {{{
             self.relayout_borders()
 
     def next_window(self) -> None:
+        '@ac:win: Focus the next window in the current tab'
         self._next_window()
 
     def previous_window(self) -> None:
+        '@ac:win: Focus the previous window in the current tab'
         self._next_window(-1)
 
     prev_window = previous_window
@@ -474,11 +517,27 @@ class Tab:  # {{{
             return self.most_recent_group(candidates)
 
     def neighboring_window(self, which: EdgeLiteral) -> None:
+        '''
+        @ac:win: Focus the neighboring window in the current tab
+
+        For example::
+
+            map ctrl+left neighboring_window left
+            map ctrl+down neighboring_window bottom
+        '''
         neighbor = self.neighboring_group_id(which)
         if neighbor:
             self.windows.set_active_group(neighbor)
 
     def move_window(self, delta: Union[EdgeLiteral, int] = 1) -> None:
+        '''
+        @ac:win: Move the window in the specified direction
+
+        For example::
+
+            map ctrl+left move_window left
+            map ctrl+down move_window bottom
+        '''
         if isinstance(delta, int):
             if self.current_layout.move_window(self.windows, delta):
                 self.relayout()
@@ -489,14 +548,17 @@ class Tab:  # {{{
                     self.relayout()
 
     def move_window_to_top(self) -> None:
+        '@ac:win: Move active window to the top (make it the first window)'
         n = self.windows.active_group_idx
         if n > 0:
             self.move_window(-n)
 
     def move_window_forward(self) -> None:
+        '@ac:win: Move active window forward (swap it with the next window)'
         self.move_window()
 
     def move_window_backward(self) -> None:
+        '@ac:win: Move active window backward (swap it with the previous window)'
         self.move_window(-1)
 
     def list_windows(self, active_window: Optional[Window], self_window: Optional[Window] = None) -> Generator[WindowDict, None, None]:
@@ -516,6 +578,10 @@ class Tab:  # {{{
     def __len__(self) -> int:
         return len(self.windows)
 
+    @property
+    def num_window_groups(self) -> int:
+        return self.windows.num_groups
+
     def __contains__(self, window: Window) -> bool:
         return window in self.windows
 
@@ -560,6 +626,9 @@ class TabManager:  # {{{
 
     @active_tab_idx.setter
     def active_tab_idx(self, val: int) -> None:
+        new_active_tab_idx = max(0, min(val, len(self.tabs) - 1))
+        if new_active_tab_idx == self._active_tab_idx:
+            return
         try:
             old_active_tab: Optional[Tab] = self.tabs[self._active_tab_idx]
         except Exception:
@@ -567,7 +636,7 @@ class TabManager:  # {{{
         else:
             assert old_active_tab is not None
             add_active_id_to_history(self.active_tab_history, old_active_tab.id)
-        self._active_tab_idx = max(0, min(val, len(self.tabs) - 1))
+        self._active_tab_idx = new_active_tab_idx
         try:
             new_active_tab: Optional[Tab] = self.tabs[self._active_tab_idx]
         except Exception:
@@ -651,6 +720,18 @@ class TabManager:  # {{{
         if len(self.tabs) > 1:
             self.set_active_tab_idx((self.active_tab_idx + len(self.tabs) + delta) % len(self.tabs))
 
+    def tab_at_location(self, loc: str) -> Optional[Tab]:
+        if loc == 'prev':
+            if self.active_tab_history:
+                old_active_tab_id = self.active_tab_history[-1]
+                for idx, tab in enumerate(self.tabs):
+                    if tab.id == old_active_tab_id:
+                        return tab
+        elif loc in ('left', 'right'):
+            delta = -1 if loc == 'left' else 1
+            idx = (len(self.tabs) + self.active_tab_idx + delta) % len(self.tabs)
+            return self.tabs[idx]
+
     def goto_tab(self, tab_num: int) -> None:
         if tab_num >= len(self.tabs):
             tab_num = max(0, len(self.tabs) - 1)
@@ -813,7 +894,7 @@ class TabManager:  # {{{
                     has_activity_since_last_focus = True
             ans.append(TabBarData(
                 title, t is at, needs_attention,
-                len(t), t.current_layout.name or '',
+                len(t), t.num_window_groups, t.current_layout.name or '',
                 has_activity_since_last_focus
             ))
         return ans
